import requests
import subprocess
import json
import os
import redis
import sys
import time 


def versions(args):
    package = args.action[1]
    r = requests.get("https://pypi.org/pypi/{}/json".format(package))
    if r.status_code == 200:
        data = r.json()
        print("Package: {}".format(package))
        print("Latest version: {}".format(data["info"]["version"]))
        print("Releases:")
        for version in data["releases"]:
            print(" - {}".format(version))
    else:
        print("Package not found")



def get_pip_freeze_output():
    try:
        pip_freeze_output = subprocess.check_output(['pip', 'freeze'], universal_newlines=True)
        return pip_freeze_output
    except subprocess.CalledProcessError as e:
        return str(e)

def poetry_dependensies():
  pip_freeze_output = get_pip_freeze_output()
  lines = pip_freeze_output.strip().split("\n")
  formatted_dependencies = []
  for line in lines:
    package, version = line.split("==")
    formatted_dependencies.append(f"{package} = \"{version}\"")
  formatted_output = "\n".join(formatted_dependencies)
  print(formatted_output)


from . import zabbix
import argparse

def main():
    parser = argparse.ArgumentParser(description="Keep kalm and automate zabbix", usage="kalm_zabbix <action> \n\n \
               \
                version : 0.0.2 (zabbix)\n\
                actions:\n\
                register          register server on zabbix  \n\
                hostgroup         list hostgroup data   for ZABBIX_HOSTGROUP  \n\
                hostgroups        list all known hostgroups \n\
               \
               2023 Knowit Miracle\
               ")
    parser.add_argument('action', metavar='<action>', type=str, nargs='+', help='setup jenkis')
    args = parser.parse_args()
    ready = False

    if args.action[0] == "status":
        print("status")
        return zabbix.status()
    
    if args.action[0] == "hostgroup":
        print("hostgroup")
        return zabbix.list_host_group()
    
    if args.action[0] == "hostgroups":
        print("hostgroups")
        return zabbix.list_host_groups()
    
    if args.action[0] == "register":
        print("register")
        return zabbix.register()    

    return 0

    

    







